@@ -1,5 +1,7 @@
 import copy
 import time
+
+import requests
 from prettytable import PrettyTable
 from pocsuite3.lib.core.common import data_to_stdout, mosaic
 from pocsuite3.lib.core.data import conf, cmd_line_options
@@ -84,16 +86,31 @@ def show_task_result():
         if row.status == 'success':
             success_num += 1
 
-    data_to_stdout('\n{0}'.format(results_table.get_string(sortby="status", reversesort=True)))
+    data_to_stdout('\n{0}'.format(results_table.get_string(sortby="status", reversesort=False)))
     data_to_stdout("\nsuccess : {} / {}\n".format(success_num, total_num))
 
 
+def check_docker_status(target):
+    if conf.docker_start:
+        info_msg = "wait for docker..."
+        logger.info(info_msg)
+        while True:
+            try:
+                resp = requests.get(target)
+                if resp.status_code:
+                    break
+            except Exception:
+                pass
+
+
 def task_run():
     while not kb.task_queue.empty() and kb.thread_continue:
         target, poc_module = kb.task_queue.get()
         if not conf.console_mode:
             poc_module = copy.deepcopy(kb.registered_pocs[poc_module])
         poc_name = poc_module.name
+        # check container status
+        check_docker_status(target)
 
         if conf.pcap:
             # start capture flow
@@ -119,8 +136,13 @@ def task_run():
             else:
                 logger.warn("No libpcap is detected, and the poc will continue to execute without fetching the packet")
                 conf.pcap = False
+        info_msg = "running poc:'{0}' target '{1}'".format(
+            poc_name,
+            mosaic(target)
+        )
 
-        info_msg = "running poc:'{0}' target '{1}'".format(poc_name, mosaic(target))
+        if len(kb.targets) > 1:
+            info_msg += ", {0} tasks waiting to be executed.".format(kb.task_queue.qsize())
 
         logger.info(info_msg)
 
