@@ -160,7 +160,6 @@ def clear_colors(message):
 
 def boldify_message(message):
     ret = message
-
     if any(_ in message for _ in BOLD_PATTERNS):
         ret = set_color(message, bold=True)
 
@@ -458,6 +457,10 @@ def parse_target(address, additional_ports=[], skip_target_port=False):
     return targets
 
 
+def parse_poc_docker_name(name):
+    return name.lower().replace(' ', '_')
+
+
 def single_time_log_message(message, level=logging.INFO, flag=None):
     if flag is None:
         flag = hash(message)
@@ -578,7 +581,7 @@ def get_poc_name(code):
     if re.search(r'register_poc', code):
         return extract_regex_result(r"""(?sm)POCBase\):.*?name\s*=\s*['"](?P<result>.*?)['"]""", code)
     elif re.search(r'matchers:\s*-', code):
-        return extract_regex_result(r"""(?sm)\s*name\s*:\s*(?P<result>[^\n]*).*matchers:""", code)
+        return extract_regex_result(r"""(?sm)\s*name\s*:\s*(?P<result>[^\r\n]*).*matchers:""", code)
     return ''
 
 
