@@ -133,8 +133,22 @@ class POC_CATEGORY:
     PROTOCOL.HTTP = "Http"
     PROTOCOL.FTP = "Ftp"
     PROTOCOL.SSH = "Ssh"
-    PROTOCOL.TELENT = "Telent"
+    PROTOCOL.TELNET = "Telnet"
     PROTOCOL.REDIS = "Redis"
+    PROTOCOL.SMTP = 'SMTP'
+    PROTOCOL.DNS = 'DNS'
+    PROTOCOL.SNMP = 'SNMP'
+    PROTOCOL.SMB = 'SMB'
+    PROTOCOL.MQTT = 'MQTT'
+    PROTOCOL.MYSQL = 'MySQL'
+    PROTOCOL.RDP = 'RDP'
+    PROTOCOL.UPNP = 'UPnP'
+    PROTOCOL.AJP = 'AJP'
+    PROTOCOL.XMPP = 'XMPP'
+    PROTOCOL.WINBOX = 'Winbox'
+    PROTOCOL.MEMCACHED = 'Memcached'
+    PROTOCOL.BACNET = 'BACnet'
+    PROTOCOL.T3 = 'T3'
 
 
 class OPTION_TYPE:
