@@ -7,7 +7,11 @@ import socket
 import importlib
 from queue import Queue
 from urllib.parse import urlsplit
+from http.client import HTTPConnection
 
+import docker.errors
+import requests
+from requests_toolbelt.adapters.socket_options import TCPKeepAliveAdapter
 import socks
 import prettytable
 from termcolor import colored
@@ -17,7 +21,9 @@ from pocsuite3.lib.core.common import boldify_message, check_file, get_file_item
 from pocsuite3.lib.core.common import check_path, extract_cookies
 from pocsuite3.lib.core.common import get_local_ip, mosaic, get_host_ip
 from pocsuite3.lib.core.common import single_time_warn_message
-from pocsuite3.lib.core.common import OrderedSet, get_file_text
+from pocsuite3.lib.core.common import OrderedSet, get_file_text, get_poc_name
+from pocsuite3.lib.core.common import index_modules, ltrim
+from pocsuite3.lib.core.common import parse_poc_docker_name
 from pocsuite3.lib.core.convert import stdout_encode
 from pocsuite3.lib.core.data import conf, cmd_line_options
 from pocsuite3.lib.core.data import kb
@@ -30,13 +36,16 @@ from pocsuite3.lib.core.exception import PocsuiteSyntaxException, PocsuiteSystem
 from pocsuite3.lib.core.log import FORMATTER
 from pocsuite3.lib.core.register import load_file_to_module
 from pocsuite3.lib.core.settings import DEFAULT_LISTENER_PORT, CMD_PARSE_WHITELIST
+from pocsuite3.lib.core.docker_env import DockerEnv
 from pocsuite3.lib.core.statistics_comparison import StatisticsComparison
 from pocsuite3.lib.core.update import update
 from pocsuite3.lib.core.template import create_poc_plugin_template
 from pocsuite3.lib.parse.cmd import DIY_OPTIONS
 from pocsuite3.lib.parse.configfile import config_file_parser
 from pocsuite3.lib.parse.rules import regex_rule
+from pocsuite3.lib.parse.dockerfile import parse_dockerfile
 from pocsuite3.lib.request.patch import patch_all
+from pocsuite3.lib.request.patch.session_reuse import api_request
 from pocsuite3.modules.listener import start_listener
 
 
@@ -51,6 +60,8 @@ def set_verbosity():
     This function set the verbosity of pocsuite output messages.
     """
 
+    HTTPConnection.debuglevel = int(conf.http_debug)
+
     if conf.verbose is None:
         conf.verbose = 1
 
@@ -194,6 +205,18 @@ def _set_network_proxy():
         }
 
 
+def _set_session_queue():
+    requests.api.request = api_request
+    for _ in range(0, conf.requests_session_reuse_num):
+        session = requests.Session()
+        session.headers.update({'Connection': 'keep-alive'})
+        # https://github.com/psf/requests/issues/6354
+        keep_alive = TCPKeepAliveAdapter()
+        session.mount("http://", keep_alive)
+        session.mount("https://", keep_alive)
+        kb.session_queue.put(session)
+
+
 def _set_multiple_targets():
     # set multi targets to kb
     if conf.url:
@@ -459,6 +482,8 @@ def _cleanup_options():
 
     if conf.output_path and 'file_record' not in conf.plugins:
         conf.plugins.append('file_record')
+    if 'web_hook' not in conf.plugins:
+        conf.plugins.append('web_hook')
 
     if conf.connect_back_port:
         conf.connect_back_port = int(conf.connect_back_port)
@@ -523,6 +548,7 @@ def _set_conf_attributes():
     conf.mode = 'verify'
     conf.poc = None
     conf.poc_keyword = None
+    conf.poc_list = None
     conf.cookie = None
     conf.host = None
     conf.referer = None
@@ -535,6 +561,7 @@ def _set_conf_attributes():
     conf.retry = 0
     conf.delay = 0
     conf.http_headers = {}
+    conf.http_debug = 0
     conf.ceye_token = None
     conf.oob_server = None
     conf.oob_token = None
@@ -556,7 +583,8 @@ def _set_conf_attributes():
     conf.dork_censys = None
     conf.dork_b64 = False
     conf.max_page = 1
-    conf.search_type = 'host'
+    conf.page_size = 20
+    conf.search_type = 'v4'
     conf.comparison = False
     conf.vul_keyword = None
     conf.ssvid = None
@@ -589,6 +617,19 @@ def _set_conf_attributes():
     conf.show_options = False
     conf.enable_tls_listener = False
 
+    # docker args
+    conf.docker_start = False
+    conf.docker_port = list()
+    conf.docker_env = list()
+    conf.docker_volume = list()
+    conf.docker_only = False
+    conf.requests_session_reuse = False
+
+    # web hook
+    conf.dingtalk_token = ""
+    conf.dingtalk_secret = ""
+    conf.wx_work_key = ""
+
 
 def _set_kb_attributes(flush_all=True):
     """
@@ -631,6 +672,7 @@ def _set_kb_attributes(flush_all=True):
     kb.current_poc = None
     kb.registered_pocs = AttribDict()
     kb.task_queue = Queue()
+    kb.session_queue = Queue()
     kb.cmd_line = DIY_OPTIONS or []
 
     kb.comparison = None
@@ -661,6 +703,46 @@ def _set_poc_options(input_options):
             DIY_OPTIONS.append(line)
 
 
+def _set_docker_options():
+    port_dict = {}
+    if conf.poc and conf.docker_start:
+        # parse port string
+        # in docker package ports need {"2222/tcp": 3333}
+        # will expose port 2222 inside the container as port 3333 on the host.
+        if len(conf.docker_port) > 0:
+            for item in conf.docker_port:
+                item_split = item.rsplit(':', 1)
+                key = '{}/tcp'.format(item_split[1])
+                # if user input 127.0.0.1:8080:8080
+                # need change to {'8080/tcp': ('127.0.0.1', 8080)}
+                if item_split[0].find(":") > 0:
+                    temp_port = item_split[0].split(':')
+                    host_port = (temp_port[0], int(temp_port[1]))
+                else:
+                    host_port = int(item_split[0])
+                port_dict[key] = host_port
+
+        for poc in conf.poc:
+            res = parse_dockerfile(poc)
+            poc_name = parse_poc_docker_name(res.get('name'))
+            tag_name = "{}:{}".format(poc_name, "pocsuite")
+            docker_file = res.get("dockerfile")
+            try:
+                dk = DockerEnv()
+                dk_info = dk.run(
+                    tag_name,
+                    docker_file,
+                    ports=port_dict,
+                    envs=conf.docker_env,
+                    volumes=conf.docker_volume,
+                )
+                logger.info("Run container {} successful!".format(dk_info.short_id))
+            except docker.errors.APIError as e:
+                logger.error(e)
+        if conf.docker_only:
+            exit(0)
+
+
 def init_options(input_options=AttribDict(), override_options=False):
     cmd_line_options.update(input_options)
     _set_conf_attributes()
@@ -754,6 +836,49 @@ def _show_pocs_modules_options():
     exit()
 
 
+def _show_pocs_form_local():
+    if not conf.poc_list:
+        return
+    _pocs = []
+    tb = prettytable.PrettyTable(["Index", "Path", "Name"])
+    if conf.pocs_path:
+        # parse user defined poc scripts path
+        if check_path(conf.pocs_path):
+            for root, dirs, files in os.walk(conf.pocs_path):
+                files = list(filter(lambda x: not x.startswith("__") and x.endswith(".py") or x.endswith(".yaml"), files))
+                conf.poc = [os.path.join(conf.pocs_path, f) for f in files]
+        moduels = index_modules(conf.pocs_path)
+        poc_parent_directory = os.sep.join(
+            conf.pocs_path.rstrip(os.sep).split(os.sep)) + os.sep
+        for poc in moduels:
+            _pocs.append(ltrim(poc, conf.pocs_path).lstrip(os.sep))
+
+    else:
+        # default poc path
+        conf.poc = [paths.POCSUITE_POCS_PATH]
+        moduels = index_modules(paths.POCSUITE_POCS_PATH)
+        poc_parent_directory = os.sep.join(
+            paths.POCSUITE_POCS_PATH.rstrip(os.sep).split(os.sep)[0:-1]) + os.sep
+        for poc in moduels:
+            _pocs.append(ltrim(poc, poc_parent_directory).lstrip(os.sep))
+    # show result table
+    try:
+        index = 0
+        for poc in _pocs:
+            file = os.path.join(poc_parent_directory, poc + ".py")
+            if not os.path.exists(file):
+                file = os.path.join(poc_parent_directory, poc + ".yaml")
+            code = get_file_text(file)
+            name = get_poc_name(code)
+            tb.add_row([str(index), poc, name])
+            index += 1
+        data_to_stdout("\n" + tb.get_string() + "\n")
+    except PocsuiteSystemException as ex:
+        logger.error(str(ex))
+    finally:
+        exit(0)
+
+
 def init():
     """
     Set attributes into both configuration and knowledge base singletons
@@ -770,9 +895,13 @@ def init():
     update()
     _set_multiple_targets()
     _set_user_pocs_path()
+    # show poc form pac path
+    _show_pocs_form_local()
     # The poc module module must be in front of the plug-in module,
     # and some parameters in the poc option call the plug-in
     _set_pocs_modules()
+    # run docker from poc
+    _set_docker_options()
     _set_plugins()
     _init_targets_plugins()
     _init_pocs_plugins()
@@ -794,3 +923,5 @@ def init():
     _set_threads()
     _set_listener()
     remove_extra_log_message()
+    if conf.requests_session_reuse:
+        _set_session_queue()
