@@ -46,6 +46,7 @@ def cmd_line_parser(argv=None):
         target.add_argument("-r", dest="poc", nargs='+', help="Load PoC file from local or remote from seebug website")
         target.add_argument("-k", dest="poc_keyword", help="Filter PoC by keyword, e.g. ecshop")
         target.add_argument("-c", dest="configFile", help="Load options from a configuration INI file")
+        target.add_argument("-l", dest="poc_list", action="store_true", help="Show all PoC file from local")
 
         # Mode options
         mode = parser.add_argument_group("Mode", "Pocsuite running mode options")
@@ -71,6 +72,12 @@ def cmd_line_parser(argv=None):
         request.add_argument("--retry", dest="retry", type=int, default=0, help="Time out retrials times (default 0)")
         request.add_argument("--delay", dest="delay", help="Delay between two request of one thread")
         request.add_argument("--headers", dest="headers", help="Extra headers (e.g. \"key1: value1\\nkey2: value2\")")
+        request.add_argument("--http-debug", dest="http_debug", type=int, default=0, help="HTTP debug level (default 0)")
+        request.add_argument("--session-reuse", dest="requests_session_reuse", action="store_true",
+                             help="Enable requests session reuse")
+        request.add_argument("--session-reuse-num", type=int, dest="requests_session_reuse_num", default=10,
+                             help="Requests session reuse number")
+
         # Account options
         group = parser.add_argument_group("Account", "Account options")
         group.add_argument("--ceye-token", dest="ceye_token", help="CEye token")
@@ -106,8 +113,11 @@ def cmd_line_parser(argv=None):
                              help="Censys dork used for search")
         modules.add_argument("--max-page", dest="max_page", type=int, default=1,
                              help="Max page used in search API")
-        modules.add_argument("--search-type", dest="search_type", action="store", default='host',
-                             help="search type used in search API, web or host")
+        modules.add_argument("--page-size", dest="page_size", type=int, default=20,
+                             help="Page size used in search API"
+                             )
+        modules.add_argument("--search-type", dest="search_type", action="store", default='v4',
+                             help="search type used in search API, v4,v6 and web")
         modules.add_argument("--vul-keyword", dest="vul_keyword", action="store", default=None,
                              help="Seebug keyword used for search")
         modules.add_argument("--ssv-id", dest="ssvid", action="store", default=None,
@@ -152,6 +162,26 @@ def cmd_line_parser(argv=None):
                                   help="Specify the name of the export rule file")
         optimization.add_argument("--no-check", dest="no_check", action="store_true", default=False,
                                   help="Disable URL protocol correction and honeypot check")
+
+        # docker options
+        docker_environment = parser.add_argument_group("Docker Environment", "Docker Environment options")
+        docker_environment.add_argument("--docker-start", dest="docker_start", action="store_true",
+                                        default=False, help="Run the docker for PoC")
+        docker_environment.add_argument("--docker-port", dest="docker_port", action="append",
+                                        default=[], help="Publish a container's port(s) to the host")
+        docker_environment.add_argument("--docker-volume", dest="docker_volume", action="append",
+                                        default=[], help="Bind mount a volume")
+        docker_environment.add_argument("--docker-env", dest="docker_env", action="append", default=[],
+                                        help="Set environment variables")
+        docker_environment.add_argument("--docker-only", dest="docker_only", action="store_true",
+                                        default=False, help="Only run docker environment")
+
+        # web hook options
+        web_hook = parser.add_argument_group('Web Hook', "Web Hook Options")
+        web_hook.add_argument("--dingtalk-token", dest="dingtalk_token", help="Dingtalk access token")
+        web_hook.add_argument("--dingtalk-secret", dest="dingtalk_secret", help="Dingtalk secret")
+        web_hook.add_argument("--wx-work-key", dest="wx_work_key", help="Weixin Work key")
+
         # Diy options
         diy = parser.add_argument_group("Poc options", "definition options for PoC")
         diy.add_argument("--options", dest="show_options", action="store_true", default=False,
