@@ -1,5 +1,6 @@
 from collections import OrderedDict
 from dataclasses import dataclass, field
+import time
 from typing import Union, List, Optional
 
 from requests_toolbelt.utils import dump
@@ -15,7 +16,7 @@ from pocsuite3.lib.yaml.nuclei.operators import (Extractor, ExtractorType,
                                                  extract_xpath, match_binary,
                                                  match_dsl, match_regex,
                                                  match_size, match_status_code,
-                                                 match_words)
+                                                 match_words, match_xpath)
 from pocsuite3.lib.yaml.nuclei.protocols.common.generators import AttackType, payload_generator
 from pocsuite3.lib.yaml.nuclei.protocols.common.interactsh import InteractshClient
 from pocsuite3.lib.yaml.nuclei.protocols.common.replacer import (
@@ -143,25 +144,13 @@ def http_response_to_dsl_map(resp: requests.Response):
     return data
 
 
-def http_get_match_part(part: str, resp_data: dict, interactsh=None, return_bytes: bool = False) -> str:
+def http_get_match_part(part: str, resp_data: dict, return_bytes: bool = False) -> str:
     result = ''
     if part == '':
         part = 'body'
 
     if part in resp_data:
         result = resp_data[part]
-    elif part.startswith('interactsh'):
-        if not isinstance(interactsh, InteractshClient):
-            result = ''
-        # poll oob data
-        else:
-            interactsh.poll()
-            if part == 'interactsh_protocol':
-                result = '\n'.join(interactsh.interactsh_protocol)
-            elif part == 'interactsh_request':
-                result = '\n'.join(interactsh.interactsh_request)
-            elif part == 'interactsh_response':
-                result = '\n'.join(interactsh.interactsh_response)
 
     if return_bytes and not isinstance(result, bytes):
         result = str(result).encode()
@@ -177,9 +166,19 @@ def http_match(request: HttpRequest, resp_data: dict, interactsh=None):
     matchers = request.matchers
     matchers_result = []
 
+    if 'interactsh_' in str(matchers) and isinstance(interactsh, InteractshClient):
+        interactsh.poll()
+        resp_data['interactsh_protocol'] = '\n'.join(interactsh.interactsh_protocol)
+        resp_data['interactsh_request'] = '\n'.join(interactsh.interactsh_request)
+        resp_data['interactsh_response'] = '\n'.join(interactsh.interactsh_response)
+    else:
+        resp_data['interactsh_protocol'] = ''
+        resp_data['interactsh_request'] = ''
+        resp_data['interactsh_response'] = ''
+
     for i, matcher in enumerate(matchers):
         matcher_res = False
-        item = http_get_match_part(matcher.part, resp_data, interactsh, matcher.type == MatcherType.BinaryMatcher)
+        item = http_get_match_part(matcher.part, resp_data, matcher.type == MatcherType.BinaryMatcher)
 
         if matcher.type == MatcherType.StatusMatcher:
             matcher_res = match_status_code(matcher, resp_data.get('status_code', 0))
@@ -199,6 +198,9 @@ def http_match(request: HttpRequest, resp_data: dict, interactsh=None):
         elif matcher.type == MatcherType.DSLMatcher:
             matcher_res = match_dsl(matcher, resp_data)
 
+        elif matcher.type == MatcherType.XpathMatcher:
+            matcher_res, _ = match_xpath(matcher, item)
+
         if matcher.negative:
             matcher_res = not matcher_res
 
@@ -256,6 +258,10 @@ def extract_dict(text, line_sep='\n', kv_sep='='):
 
 def http_request_generator(request: HttpRequest, dynamic_values: OrderedDict):
     request_count = len(request.path + request.raw)
+    # Determine the number of requests and modify the req_condition attribute of the HttpRequest object
+    if request_count > 1:
+        request.req_condition = True
+
     for payload_instance in payload_generator(request.payloads, request.attack):
         current_index = 0
         dynamic_values.update(payload_instance)
@@ -274,9 +280,14 @@ def http_request_generator(request: HttpRequest, dynamic_values: OrderedDict):
             else:
                 raw = path.strip()
                 raws = list(map(lambda x: x.strip(), raw.splitlines()))
-                method, path, _ = raws[0].split(' ')
-                url = f'{Marker.ParenthesisOpen}BaseURL{Marker.ParenthesisClose}{path}'
-
+                # Extract timeout value
+                if raws[0].startswith('@timeout'):
+                    timeout = Marker.extract_timeout_value(raws[0])
+                    del raws[0]
+                    method, path, _ = raws[0].split(' ')
+                    kwargs.setdefault('timeout', timeout)
+                else:
+                    method, path, _ = raws[0].split(' ')
                 if method == "POST":
                     index = 0
                     for i in raws:
@@ -288,10 +299,12 @@ def http_request_generator(request: HttpRequest, dynamic_values: OrderedDict):
 
                     headers = raws[1:index - 1]
                     headers = extract_dict('\n'.join(headers), '\n', ": ")
-                    data = raws[index]
+                    data = '\n'.join(raws[index:])
                 else:
                     headers = extract_dict('\n'.join(raws[1:]), '\n', ": ")
 
+                url = f'{Marker.ParenthesisOpen}BaseURL{Marker.ParenthesisClose}{path}'
+
             kwargs.setdefault('allow_redirects', request.redirects)
             kwargs.setdefault('data', data)
             kwargs.setdefault('headers', headers)
@@ -326,7 +339,13 @@ def execute_http_request(request: HttpRequest, dynamic_values, interactsh) -> Un
                         session.max_redirects = request.max_redirects
                     else:
                         session.max_redirects = 10
+
+                    # Calculate response time
+                    start_time = time.time()
                     response = session.request(method=method, url=url, **kwargs)
+                    end_time = time.time()
+                    resp_time = end_time - start_time
+
                     # for debug purpose
                     try:
                         logger.debug(dump.dump_all(response).decode('utf-8'))
@@ -339,6 +358,9 @@ def execute_http_request(request: HttpRequest, dynamic_values, interactsh) -> Un
                     response = None
 
                 resp_data = http_response_to_dsl_map(response)
+                if response is not None:
+                    resp_data['duration'] = resp_time
+
                 if response:
                     response.close()
 
