@@ -5,37 +5,39 @@ import time
 import re
 from configparser import ConfigParser
 
-from pocsuite3.lib.core.data import logger
-from pocsuite3.lib.core.data import paths
+from pocsuite3.api import conf
+from pocsuite3.lib.core.data import logger, paths
 from pocsuite3.lib.request import requests
 from pocsuite3.lib.utils import get_middle_text, random_str
 
 
 class CEye(object):
-    def __init__(self, conf_path=paths.POCSUITE_RC_PATH, username=None, password=None, token=None):
+    def __init__(self, conf_path=paths.POCSUITE_RC_PATH, token=None):
+        self.url = 'http://api.ceye.io/v1'
+        self.identify = ''
         self.headers = {'User-Agent': 'curl/7.80.0'}
         self.token = token
+        if 'ceye_token' in conf:
+            self.token = self.token or conf.ceye_token
         self.conf_path = conf_path
-        self.username = username
-        self.password = password
 
         if self.conf_path:
             self.parser = ConfigParser()
             self.parser.read(self.conf_path)
             try:
-                self.token = self.token or self.parser.get("Telnet404", 'Jwt token')
+                self.token = self.token or self.parser.get('CEye', 'token')
             except Exception:
                 pass
 
-        self.check_account()
+        self.check_token()
 
     def token_is_available(self):
         if self.token:
-            # distinguish Jwt Token & API Token
-            self.headers['Authorization'] = self.token if len(self.token) < 48 else f'JWT {self.token}'
             try:
-                resp = requests.get('http://api.ceye.io/v1/identify', headers=self.headers)
-                if resp and resp.status_code == 200 and "identify" in resp.text:
+                self.headers['Authorization'] = self.token
+                resp = requests.get(f'{self.url}/identify', headers=self.headers)
+                if resp and resp.status_code == 200 and 'identify' in resp.text:
+                    self.identify = resp.json()['data']['identify']
                     return True
                 else:
                     logger.info(resp.text)
@@ -43,50 +45,31 @@ class CEye(object):
                 logger.error(str(ex))
         return False
 
-    def new_token(self):
-        data = '{{"username": "{}", "password": "{}"}}'.format(self.username, self.password)
-        try:
-            resp = requests.post('https://api.zoomeye.org/user/login', data=data)
-            if resp.status_code != 401 and "access_token" in resp.text:
-                content = resp.json()
-                self.token = content['access_token']
-                self.headers['Authorization'] = f'JWT {self.token}'
-                return True
-            else:
-                logger.info(resp.text)
-        except Exception as ex:
-            logger.error(str(ex))
-        return False
-
     def check_account(self):
+        return self.check_token()
+
+    def check_token(self):
         if self.token_is_available():
             return True
-        elif self.username and self.password:
-            if self.new_token():
-                self.write_conf()
-                return True
+
         while True:
-            username = input("Telnet404 email account: ")
-            password = getpass.getpass("Telnet404 password: (input will hidden)")
-            self.username = username
-            self.password = password
-            if self.new_token():
+            self.token = getpass.getpass('CEye API token: (input will hidden)')
+            if self.token_is_available():
                 self.write_conf()
                 return True
             else:
-                logger.error("The username or password is incorrect, "
-                             "Please enter the correct username and password.")
+                logger.error('The CEye api token is incorrect, Please enter the correct api token.')
 
     def write_conf(self):
-        if not self.parser.has_section("Telnet404"):
-            self.parser.add_section("Telnet404")
+        if not self.parser.has_section('CEye'):
+            self.parser.add_section('CEye')
         try:
-            self.parser.set("Telnet404", "Jwt token", self.token)
+            self.parser.set('CEye', 'token', self.token)
             self.parser.write(open(self.conf_path, "w"))
         except Exception as ex:
             logger.error(str(ex))
 
-    def verify_request(self, flag, type="request"):
+    def verify_request(self, flag, type='request'):
         """
         Check whether the ceye interface has data
 
@@ -96,9 +79,7 @@ class CEye(object):
         """
         ret_val = False
         counts = 3
-        url = (
-            "http://api.ceye.io/v1/records?token={token}&type={type}&filter={flag}"
-        ).format(token=self.token, type=type, flag=flag)
+        url = f'{self.url}/records?token={self.token}&type={type}&filter={flag}'
         while counts:
             try:
                 time.sleep(1)
@@ -121,9 +102,7 @@ class CEye(object):
         :return: Return the acquired data
         """
         counts = 3
-        url = (
-            "http://api.ceye.io/v1/records?token={token}&type={type}&filter={flag}"
-        ).format(token=self.token, type=type, flag=flag)
+        url = f'{self.url}/records?token={self.token}&type={type}&filter={flag}'
         while counts:
             try:
                 time.sleep(1)
@@ -161,24 +140,17 @@ class CEye(object):
         ranstr = random_str(4)
         domain = self.getsubdomain()
         url = ""
-        if type == "request":
+        if type in ["request", 'http']:
             url = "http://{}.{}/{}{}{}".format(ranstr, domain, ranstr, value, ranstr)
         elif type == "dns":
-            url = "{}{}{}.{}".format(ranstr, re.sub("\W", "", value), ranstr, domain)
+            url = "{}{}{}.{}".format(ranstr, re.sub(r"\W", "", value), ranstr, domain)
         return {"url": url, "flag": ranstr}
 
     def getsubdomain(self):
         """
-        Obtain subdomains through ceye token
         :return: Return the obtained domain name
         """
-        r = requests.get("http://api.ceye.io/v1/identify", headers=self.headers).json()
-        suffix = ".ceye.io"
-        try:
-            indetify = r["data"]["identify"]
-        except KeyError:
-            return None
-        return indetify + suffix
+        return f'{self.identify}.ceye.io'
 
 
 if __name__ == "__main__":
