@@ -2,6 +2,7 @@ from .reverse_tcp import handle_listener_connection
 from .reverse_tcp import start_listener
 from .reverse_tcp import REVERSE_PAYLOAD
 from .bind_tcp import (bind_shell, bind_tcp_shell, bind_telnet_shell)
+from .bind_tcp import BIND_PAYLOAD
 
 __all__ = ('handle_listener_connection', 'start_listener', 'REVERSE_PAYLOAD',
-           'bind_shell', 'bind_tcp_shell', 'bind_telnet_shell')
+           'bind_shell', 'bind_tcp_shell', 'bind_telnet_shell', 'BIND_PAYLOAD')
