@@ -67,7 +67,7 @@ class Shodan():
             for page in range(1, pages + 1):
                 time.sleep(1)
                 url = f"{self.url}/shodan/{resource}/search?key={self.token}&query={dork}&page={page}"
-                resp = requests.get(url, headers=self.headers)
+                resp = requests.get(url, headers=self.headers, timeout=60)
                 if resp and resp.status_code == 200 and "total" in resp.json():
                     content = resp.json()
                     for match in content['matches']:
